@@ -1,6 +1,6 @@
 /* vim: set expandtab ts=8 sw=4: */
 
-/*  $Id: xfce-panel-external-plugin.c 20070 2006-02-25 22:33:57Z jasper $
+/*  $Id: xfce-panel-external-plugin.c 21753 2006-05-21 11:13:48Z jasper $
  *
  *  Copyright © 2005 Jasper Huijsmans <jasper@xfce.org>
  *
@@ -75,13 +75,6 @@ struct _XfceExternalPanelPluginPrivate
 static void xfce_external_panel_plugin_interface_init (gpointer g_iface,
                                                        gpointer data);
 
-static void
-xfce_external_panel_plugin_class_init (XfceExternalPanelPluginClass * class);
-
-static void 
-xfce_external_panel_plugin_init (XfceExternalPanelPlugin * plugin);
-
-
 /* GObject */
 static void xfce_external_panel_plugin_finalize (GObject * object);
 
