@@ -1,6 +1,6 @@
 /* vim: set expandtab ts=8 sw=4: */
 
-/*  $Id: panel-app.c 20870 2006-04-13 20:53:17Z jasper $
+/*  $Id: panel-app.c 21122 2006-04-20 19:58:31Z jasper $
  *
  *  Copyright © 2005 Jasper Huijsmans <jasper@xfce.org>
  *
@@ -731,7 +731,7 @@ panel_app_remove_panel (GtkWidget *panel)
     if (panel_app.panel_list->len == 1)
     {
         response = 
-            xfce_message_dialog (GTK_WINDOW (panel), _("Xfce Panel"),
+            xfce_message_dialog (NULL, _("Xfce Panel"),
                                  GTK_STOCK_DIALOG_WARNING, 
                                  _("Exit Xfce Panel?"), 
                                  _("You can't remove the last panel. "
