@@ -1,6 +1,6 @@
 /* vim: set expandtab ts=8 sw=4: */
 
-/*  $Id: panel-properties.c 20870 2006-04-13 20:53:17Z jasper $
+/*  $Id: panel-properties.c 22233 2006-07-01 06:33:29Z olivier $
  *
  *  Copyright © 2005 Jasper Huijsmans <jasper@xfce.org>
  *
@@ -315,6 +315,11 @@ _set_struts (Panel *panel, XfceMonitor *xmon, int x, int y, int w, int h)
 			 gdk_atom_intern ("CARDINAL", FALSE), 32,
 			 GDK_PROP_MODE_REPLACE, (guchar *) & data, 12);
 
+    gdk_property_change (GTK_WIDGET (panel)->window,
+			 gdk_atom_intern ("_NET_WM_STRUT", FALSE),
+			 gdk_atom_intern ("CARDINAL", FALSE), 32,
+			 GDK_PROP_MODE_REPLACE, (guchar *) & data, 4);
+
     gdk_error_trap_pop ();
 }
 
