@@ -1,6 +1,6 @@
 /* vim: set expandtab ts=8 sw=4: */
 
-/*  $Id: iconbox.c 20349 2006-03-12 09:04:43Z jasper $
+/*  $Id: iconbox.c 21756 2006-05-21 12:59:15Z jasper $
  *
  *  Copyright © 2005 Jasper Huijsmans <jasper@xfce.org>
  *
@@ -779,33 +779,26 @@ iconbox_dialog_response (GtkWidget *dlg, int reponse,
 static void
 iconbox_properties_dialog (XfcePanelPlugin *plugin, Iconbox *iconbox)
 {
-    GtkWidget *dlg, *header, *vbox, *cb;
+    GtkWidget *dlg, *vbox, *cb;
 
     xfce_panel_plugin_block_menu (plugin);
     
-    dlg = gtk_dialog_new_with_buttons (_("Properties"), 
+    dlg = xfce_titled_dialog_new_with_buttons (_("Icon Box"),
                 GTK_WINDOW (gtk_widget_get_toplevel (GTK_WIDGET (plugin))),
-                GTK_DIALOG_DESTROY_WITH_PARENT |
-                GTK_DIALOG_NO_SEPARATOR,
+                GTK_DIALOG_DESTROY_WITH_PARENT | GTK_DIALOG_NO_SEPARATOR,
                 GTK_STOCK_CLOSE, GTK_RESPONSE_OK,
                 NULL);
-    
+
     g_object_set_data (G_OBJECT (plugin), "dialog", dlg);
 
     gtk_window_set_position (GTK_WINDOW (dlg), GTK_WIN_POS_CENTER);
+    gtk_window_set_icon_name (GTK_WINDOW (dlg), "xfce4-settings");
     
     g_signal_connect (dlg, "response", G_CALLBACK (iconbox_dialog_response),
                       iconbox);
 
     gtk_container_set_border_width (GTK_CONTAINER (dlg), 2);
     
-    header = xfce_create_header (NULL, _("Icon Box"));
-    gtk_widget_set_size_request (GTK_BIN (header)->child, 200, 32);
-    gtk_container_set_border_width (GTK_CONTAINER (header), 6);
-    gtk_widget_show (header);
-    gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dlg)->vbox), header,
-                        FALSE, TRUE, 0);
-    
     vbox = gtk_vbox_new (FALSE, 8);
     gtk_container_set_border_width (GTK_CONTAINER (vbox), 6);
     gtk_widget_show (vbox);
