@@ -1,6 +1,6 @@
 /* vim: set expandtab ts=8 sw=4: */
 
-/*  $Id: launcher.c 20853 2006-04-11 20:41:56Z olivier $
+/*  $Id: launcher.c 21876 2006-05-28 15:41:24Z jasper $
  *
  *  Copyright © 2005 Jasper Huijsmans <jasper@xfce.org>
  *
@@ -162,41 +162,20 @@ launcher_construct (XfcePanelPlugin *plugin)
  *                   Launcher Plugin Interface                          *
  * -------------------------------------------------------------------- */
 
-static const char *icon_categories[XFCE_N_BUILTIN_ICON_CATEGORIES][2] =
-{
-	{ "xfce-unknown",       "dialog-question" },
-	{ "xfce-edit",          "accessories-text-editor" },
-	{ "xfce-filemanager",   "system-file-manager" },
-	{ "xfce-utils",         "applications-accessories" },
-	{ "xfce-games",         "applications-games" },
-	{ "xfce-man",           "system-help" },
-	{ "xfce-multimedia",    "applications-multimedia" },
-	{ "xfce-internet",      "applications-internet" },
-	{ "xfce-graphics",      "applications-graphics" },
-	{ "xfce-printer",       "printer" },
-	{ "xfce-schedule",      "clock" },
-	{ "xfce-sound",         "audio-volume-medium" },
-	{ "xfce-terminal",      "utilities-terminal" },
-	{ "xfce-devel",         "applications-development" },
-	{ "xfce-settings",      "preferences-desktop" },
-	{ "xfce-system",        "applications-system" },
-	{ "xfce-wine",          "wine" }
-};
-
 static LauncherPlugin *open_launcher = NULL;
 
 
 /* DND *
  * --- */
 
-static GtkTargetEntry target_list [] =
+static const GtkTargetEntry target_list [] =
 {
     { "text/uri-list", 0, TARGET_URI_LIST },
     { "text/x-moz-url", 0, TARGET_MOZ_URL },
     { "STRING", 0, TARGET_URI_LIST }
 };
 
-static guint n_targets = G_N_ELEMENTS (target_list);
+static const guint n_targets = G_N_ELEMENTS (target_list);
 
 /* Mozilla uses its own weird format. */
 static void
@@ -346,28 +325,12 @@ launcher_icon_load_pixbuf (GtkWidget *w, LauncherIcon * icon, int size)
     }
     else if (icon->type == LAUNCHER_ICON_TYPE_CATEGORY)
     {
-        /* first try name from icon nameing spec... */
-        pb = xfce_themed_icon_load (icon_categories[icon->icon.category][1],
-                                    size);
-        /* ...then try xfce name, if necessary */
-        if (!pb)
-        {
-            pb = 
-                xfce_themed_icon_load (icon_categories[icon->icon.category][0],
-                                       size);
-        }
+        pb = xfce_themed_icon_load_category (icon->icon.category, size);
     }
 
     if (!pb)
     {
-        /* first try name from icon nameing spec... */
-        pb = xfce_themed_icon_load (icon_categories[0][1], size);
-        
-        /* ...then try xfce name, if necessary */
-        if (!pb)
-        {
-            pb = xfce_themed_icon_load (icon_categories[0][0], size);
-        }
+        pb = xfce_themed_icon_load_category (XFCE_ICON_CATEGORY_UNKNOWN, size);
     }
 
     return pb;
@@ -482,6 +445,35 @@ launcher_entry_drop_cb (GdkScreen *screen, LauncherEntry *entry,
     g_free (argv);
 }
 
+static void
+launcher_entry_clipboard_cb (GdkScreen *screen, LauncherEntry *entry)
+{
+    char *paste = NULL;
+    GtkClipboard *clip;
+
+    clip = gtk_clipboard_get (GDK_SELECTION_PRIMARY);
+    if (clip)
+        paste = gtk_clipboard_wait_for_text (clip);
+
+    if (paste != NULL)
+    {
+        GPtrArray *files;
+        char *tmp;
+
+        tmp = g_strescape (paste, NULL);
+        g_free (paste);
+        paste = tmp;
+
+        files = g_ptr_array_sized_new (1);
+        g_ptr_array_add (files, paste);
+
+        launcher_entry_drop_cb (screen, entry, files);
+
+        g_free (paste);
+        g_ptr_array_free (files, TRUE);
+    }
+}
+
 static void
 launcher_entry_data_received (GtkWidget *widget, GdkDragContext *context, 
                               gint x, gint y, GtkSelectionData *data, 
@@ -558,6 +550,21 @@ launcher_button_released (GtkWidget *mi, GdkEventButton *ev,
         return TRUE;
     }
     
+    if (ev->button == 2)
+    {
+        LauncherEntry *entry = 
+            g_object_get_data (G_OBJECT (mi), "launcher_entry");
+
+        if (entry != NULL)
+        {
+            launcher_entry_clipboard_cb (gtk_widget_get_screen (mi), entry);
+
+            gtk_menu_popdown (GTK_MENU (launcher->menu));
+            launcher_menu_deactivated(launcher->menu, launcher);
+        }
+        return TRUE;
+    }
+
     /* don't activate on right-click */
     if (ev->button == 3)
         return TRUE;
@@ -813,11 +820,11 @@ launcher_position_menu (GtkMenu * menu, int *x, int *y, gboolean * push_in,
 static gboolean
 real_toggle_menu (LauncherPlugin *launcher)
 {
-    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (launcher->arrowbutton), 
-                                                     TRUE);
-    
-    if (launcher->entries->len > 1)
+    if (launcher->menu)
     {
+        gtk_toggle_button_set_active (
+                GTK_TOGGLE_BUTTON (launcher->arrowbutton), TRUE);
+    
         xfce_panel_plugin_register_menu (XFCE_PANEL_PLUGIN (launcher->plugin), 
                                          GTK_MENU (launcher->menu));
 
@@ -835,8 +842,15 @@ static gboolean
 launcher_toggle_menu_timeout (GtkToggleButton *b, GdkEventButton *ev, 
                               LauncherPlugin *launcher)
 {
-    if (ev->button != 1)
+    guint modifiers;
+
+    modifiers = gtk_accelerator_get_default_mod_mask ();
+
+    if (ev->button != 1 || (ev->button == 1 && 
+        (ev->state & modifiers) == GDK_CONTROL_MASK))
+    {
         return FALSE;
+    }
 
     if (launcher->popup_timeout < 1)
     {
@@ -854,9 +868,16 @@ static gboolean
 launcher_toggle_menu (GtkToggleButton *b, GdkEventButton *ev, 
                       LauncherPlugin *launcher)
 {
-    if (ev->button != 1)
+    guint modifiers;
+
+    modifiers = gtk_accelerator_get_default_mod_mask ();
+
+    if (ev->button != 1 || (ev->button == 1 && 
+        (ev->state & modifiers) == GDK_CONTROL_MASK))
+    {
         return FALSE;
-    
+    }
+
     real_toggle_menu (launcher);
 
     return TRUE;
@@ -933,6 +954,20 @@ launcher_clicked (GtkWidget *w, LauncherPlugin *launcher)
                          g_ptr_array_index (launcher->entries, 0));
 }
 
+static gboolean
+launcher_released (GtkWidget *b, GdkEventButton *ev, LauncherPlugin *launcher)
+{
+    if (ev->button == 2)
+    {
+        LauncherEntry *entry = g_ptr_array_index (launcher->entries, 0);
+
+        launcher_entry_clipboard_cb (gtk_widget_get_screen (b), entry);
+
+        return TRUE;
+    }
+
+    return FALSE;
+}
 
 /* Read Configuration Data */
 
@@ -1237,6 +1272,9 @@ launcher_new (XfcePanelPlugin *plugin)
     g_signal_connect (launcher->iconbutton, "clicked",
                       G_CALLBACK (launcher_clicked), launcher);
     
+    g_signal_connect (launcher->iconbutton, "button-release-event",
+                      G_CALLBACK (launcher_released), launcher);
+    
     g_signal_connect (launcher->arrowbutton, "button-press-event",
                       G_CALLBACK (launcher_toggle_menu), launcher);
     
